import { TimeConverter } from '@modules/ad/infrastructure/time-converter';

describe('Time Converter', () => {
  it('should be defined', () => {
    const timeConverter: TimeConverter = new TimeConverter();
    expect(timeConverter).toBeDefined();
  });
  it('should convert a paris datetime to utc', () => {
    const timeConverter: TimeConverter = new TimeConverter();
    const parisDate = '2023-06-22';
    const parisTime = '08:00';
    const utcDatetime = timeConverter.dateTimeToUtc(
      parisDate,
      parisTime,
      'Europe/Paris',
    );
    expect(utcDatetime.toISOString()).toEqual('2023-06-22T06:00:00.000Z');
  });
  it('should return undefined if date is invalid', () => {
    const timeConverter: TimeConverter = new TimeConverter();
    const parisDate = '2023-16-22';
    const parisTime = '08:00';
    const utcDatetime = timeConverter.dateTimeToUtc(
      parisDate,
      parisTime,
      'Europe/Paris',
    );
    expect(utcDatetime).toBeUndefined();
  });
  it('should return undefined if time is invalid', () => {
    const timeConverter: TimeConverter = new TimeConverter();
    const parisDate = '2023-06-22';
    const parisTime = '28:00';
    const utcDatetime = timeConverter.dateTimeToUtc(
      parisDate,
      parisTime,
      'Europe/Paris',
    );
    expect(utcDatetime).toBeUndefined();
  });
  it('should return undefined if timezone is invalid', () => {
    const timeConverter: TimeConverter = new TimeConverter();
    const parisDate = '2023-06-22';
    const parisTime = '08:00';
    const utcDatetime = timeConverter.dateTimeToUtc(
      parisDate,
      parisTime,
      'Foo/Bar',
    );
    expect(utcDatetime).toBeUndefined();
  });
});
